JSON-LD Contexts — linkml documentation

# JSON-LD Contexts

Warning

The JSON-LD context generator does not yet include `@embed` directives necessary for conversion from RDF.

Warning

The JSON-LD context generator does not yet include `@type` directives except at the top level.

## Overview

JSON-LD context provides mapping from JSON to RDF.

    gen-jsonld-context personinfo.yaml > personinfo.context.jsonld

You can control the output via prefixes declarations and default_curi_maps.

Any JSON that conforms to the derived JSON Schema (see above) can be converted to RDF using this context.

You can also combine a JSON instance file with a JSON-LD context using simple code or a tool like jq:

    jq -s '.[0] * .[1]' examples/organization-data.json examples/organization.context.jsonld > examples/organization-data.jsonld

The above generated JSON-LD file can be converted to other RDF serialization formats such as N-Triples. For example we can use Apache Jena as follows:

    riot examples/organization-data.jsonld > examples/organization-data.nt

## Docs

### Command Line

### Code